### IMPORTANT: Please do not create a Pull Request without creating an 
issue first.

### Title   
 feat(api): add Foo to Bar

### Description
A one to two sentence summary of the PR for easy digestion, must be 
different and more descriptive than title. Combination of tile and 
description should summarize the issue + solution.

### Reviewers
List all reviewers here and briefly describe why they are invited for 
review.
By default, the PR author should merge once the reviewers have had a 
chance to review.
If you have a different preference or cannot merge after review for some 
other constraint, leave a note about it here.

### Changes
List your changes

### Acceptance Criteria
What needs to happen functionally for this work to pass review

### Related Issue(s)
Remove this line and link your issue here Issue #1234 - Add Foo to Bar.

### Testing
Add how you tested this PR AND add steps for testing this PR.

